sequencetools.negate_sequence_elements_at_indices
=================================================

.. autofunction:: abjad.tools.sequencetools.negate_sequence_elements_at_indices.negate_sequence_elements_at_indices
